aboutsummaryrefslogtreecommitdiffstats
path: root/boot.php
diff options
context:
space:
mode:
authorfriendica <info@friendica.com>2013-05-01 02:23:40 -0700
committerfriendica <info@friendica.com>2013-05-01 02:23:40 -0700
commitd517b4fdf507172f87daae3f04e182b1aa61e64c (patch)
tree060906e017888f2a17b5c4d9c303a58729bbb8b3 /boot.php
parent72a770ae36eb75d86187800d28c2cd34806f185a (diff)
downloadvolse-hubzilla-d517b4fdf507172f87daae3f04e182b1aa61e64c.tar.gz
volse-hubzilla-d517b4fdf507172f87daae3f04e182b1aa61e64c.tar.bz2
volse-hubzilla-d517b4fdf507172f87daae3f04e182b1aa61e64c.zip
change plugin_install to plugin_load, etc.
Diffstat (limited to 'boot.php')
-rw-r--r--boot.php6
1 files changed, 3 insertions, 3 deletions
diff --git a/boot.php b/boot.php
index 33d9a2ee9..1cb30bdc4 100644
--- a/boot.php
+++ b/boot.php
@@ -1118,7 +1118,7 @@ function check_config(&$a) {
* $a->config['system']['addon'] contains a comma-separated list of names
* of plugins/addons which are used on this system.
* Go through the database list of already installed addons, and if we have
* an entry, but it isn't in the config list, call the uninstall procedure
* and mark it uninstalled in the database (for now we'll remove it).
* Then go through the config list and if we have a plugin that isn't installed,
* call the install procedure and add it to the database.
@@ -1144,7 +1144,7 @@ function check_config(&$a) {
if(count($installed)) {
foreach($installed as $i) {
if(! in_array($i['name'],$plugins_arr)) {
- uninstall_plugin($i['name']);
+ unload_plugin($i['name']);
}
else {
$installed_arr[] = $i['name'];
@@ -1155,7 +1155,7 @@ function check_config(&$a) {
if(count($plugins_arr)) {
foreach($plugins_arr as $p) {
if(! in_array($p,$installed_arr)) {
- install_plugin($p);
+ load_plugin($p);
}
}
}
@@ -1118,7 +1118,7 @@ function check_config(&$a) {
* of plugins/addons which are used on this system.
* Go through the database list of already installed addons, and if we have
- * an entry, but it isn't in the config list, call the uninstall procedure
+ * an entry, but it isn't in the config list, call the unload procedure
* and mark it uninstalled in the database (for now we'll remove it).
* Then go through the config list and if we have a plugin that isn't installed,